package Catmandu::SRU;

=head1 NAME

Catmandu::SRU - Catmandu module for working with SRU data

=head1 VERSION

Version 0.033

=cut

our $VERSION = '0.033';

=head1 MODULES

L<Catmandu::Importer::SRU>

=head1 AUTHOR

Wouter Willaert, C<< <wouterw@inuits.eu> >>

=head1 CONTRIBUTORS

Patrick Hochstenbach, C<< <patrick.hochstenbach at ugent.be> >>

Jakob Voss C<< jakob.voss@gbv.de >>

=head1 LICENSE AND COPYRIGHT

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=encoding utf8

=cut

1;
