use strict;
use warnings;
use Module::Build;

my $builder = Module::Build->new(
    module_name => 'Catmandu::SRU',
    license => 'perl',
    dist_author => [
        'Wouter Willaert <wouterw@inuits.eu>'
    ],
    dist_version_from => 'lib/Catmandu/SRU.pm',
    build_requires => {
        'Software::License' => 0,
        'Test::Exception' => 0,
        'Test::More' => 0,
    },
    requires => {
        'perl' => '5.10.1',
        'Catmandu' => '0.0302',
        'Furl' => '0.41',
        'XML::LibXML::Simple' => '0.91',
        'XML::Struct' => '0.16',
        'Moo' => '1.000003',
        'URI::Escape' => '1.60',
    },
    add_to_cleanup => [qw(
        Catmandu-SRU*
    )],
    create_makefile_pl => 'traditional',
    create_license => 1,
    meta_merge => {
        resources => {
            repository => 'https://github.com/LibreCat/Catmandu-SRU',
            bugtracker => 'https://github.com/LibreCat/Catmandu-SRU/issues',
        }
    },
);

$builder->create_build_script;
